@@ -8,6 +8,7 @@ Tests for `skbuild.setup` function.
 """
 
 import textwrap
+import sys
 import os
 import pprint
 import py.path
@@ -312,6 +313,9 @@ def test_cmake_minimum_required_version_keyword():
                            "See https://github.com/conda/conda/issues/508")
 @pytest.mark.skipif(not is_site_reachable("https://pypi.org/simple/cmake/"),
                     reason="pypi.org website not reachable")
+@pytest.mark.xfail(sys.platform.startswith("win"),
+                   reason="Timing issue with Ninja & MSVC 2019- needs investigation",
+                   strict=False)
 def test_setup_requires_keyword_include_cmake(mocker, capsys):
 
     mock_setup = mocker.patch('skbuild.setuptools_wrap.upstream_setup')
@@ -737,7 +741,6 @@ def test_setup_inputs(
             c_off='' if has_cmake_package else '#',
             cm_off='' if has_cmake_module else '#',
             h_off='' if has_hybrid_package else '#',
-            p_off='' if has_pure_package else '#'
         )
     ))
 
